// Default timeout in minutes
const DEFAULT_TIMEOUT = 30;

let lastActivity = Date.now();
let timeoutMinutes = DEFAULT_TIMEOUT;
let isEnabled = true;

// Load saved settings
chrome.storage.sync.get({
    enabled: true,
    timeoutMinutes: DEFAULT_TIMEOUT
}, (items) => {
    isEnabled = items.enabled;
    timeoutMinutes = items.timeoutMinutes;
    console.log('Settings loaded:', { isEnabled, timeoutMinutes });
});

// Function to update last activity time
function updateLastActivity() {
    if (isEnabled) {
        lastActivity = Date.now();
        console.log('Activity detected, timer reset');
    }
}

// Function to check if user is logged into Gmail
function isLoggedIn() {
    // Check multiple elements that indicate being logged in
    const menuButton = document.querySelector('div[aria-label="Main menu"]');
    const composeButton = document.querySelector('div[role="button"][gh="cm"]');
    const inboxLink = document.querySelector('a[href$="inbox"]');
    
    return menuButton !== null || composeButton !== null || inboxLink !== null;
}

// Function to force logout
function forceLogout() {
    console.log('Logging out...');
    // Try multiple logout methods
    const logoutUrl = 'https://mail.google.com/mail/logout';
    const accountsLogoutUrl = 'https://accounts.google.com/Logout';
    
    // First try to fetch the logout URL
    fetch(logoutUrl, { credentials: 'include' })
        .then(() => {
            console.log('Logout successful');
            window.location.href = logoutUrl;
        })
        .catch(() => {
            console.log('Trying alternative logout');
            window.location.href = accountsLogoutUrl;
        });
}

// Add activity listeners
document.addEventListener('mousemove', updateLastActivity);
document.addEventListener('keypress', updateLastActivity);
document.addEventListener('click', updateLastActivity);
document.addEventListener('scroll', updateLastActivity);

// Listen for messages from background script and popup
chrome.runtime.onMessage.addListener((message, sender, sendResponse) => {
    if (message.type === 'check_logout') {
        if (isEnabled && isLoggedIn()) {
            const currentTime = Date.now();
            const timeDiff = (currentTime - lastActivity) / 1000 / 60; // Convert to minutes
            console.log('Time since last activity:', timeDiff, 'minutes');

            if (timeDiff >= timeoutMinutes) {
                console.log('Timeout reached, logging out');
                forceLogout();
            }
        }
        sendResponse({ status: 'checked' });
    } else if (message.type === 'settings_updated') {
        isEnabled = message.settings.enabled;
        timeoutMinutes = message.settings.timeoutMinutes;
        lastActivity = Date.now(); // Reset timer when settings are updated
        console.log('Settings updated:', { isEnabled, timeoutMinutes });
        sendResponse({ status: 'updated' });
    }
    return true; // Keep the message channel open for async response
});
