document.addEventListener('DOMContentLoaded', () => {
    const enabledCheckbox = document.getElementById('enabled');
    const timeoutInput = document.getElementById('timeout');
    const timeUnitSelect = document.getElementById('timeUnit');
    const saveButton = document.getElementById('save');

    // Load saved settings
    chrome.storage.sync.get({
        enabled: true,
        timeoutMinutes: 30
    }, (items) => {
        enabledCheckbox.checked = items.enabled;
        
        // Convert minutes to appropriate unit
        if (items.timeoutMinutes >= 60 && items.timeoutMinutes % 60 === 0) {
            timeoutInput.value = items.timeoutMinutes / 60;
            timeUnitSelect.value = '60';
        } else {
            timeoutInput.value = items.timeoutMinutes;
            timeUnitSelect.value = '1';
        }
    });

    // Save settings
    saveButton.addEventListener('click', () => {
        const timeout = parseInt(timeoutInput.value) * parseInt(timeUnitSelect.value);
        
        chrome.storage.sync.set({
            enabled: enabledCheckbox.checked,
            timeoutMinutes: timeout
        }, () => {
            // Update status to show settings were saved
            saveButton.textContent = 'נשמר!';
            setTimeout(() => {
                saveButton.textContent = 'שמור הגדרות';
            }, 1500);

            // Notify content script and background script of changes
            chrome.tabs.query({url: 'https://mail.google.com/*'}, (tabs) => {
                tabs.forEach(tab => {
                    chrome.tabs.sendMessage(tab.id, {
                        type: 'settings_updated',
                        settings: {
                            enabled: enabledCheckbox.checked,
                            timeoutMinutes: timeout
                        }
                    });
                });
            });
        });
    });
});
